

Cicero: Serving presentation slides written in Markdown
=======================================================

You **write your talk in Markdown**, host it on
`GitHub <https://github.com>`__
or
`GitLab <https://gitlab.com>`__.
**We render it** using
`remark <https://remarkjs.com>`__
of
`reveal.js <https://revealjs.com>`__
and serve it for you
before you can say blueberry pie.
You can **style your slides** to your heart's content.


.. toctree::
   :maxdepth: 1
   :caption: First steps

   getting_started.rst


.. toctree::
   :maxdepth: 1
   :caption: Exporting slides

   export.rst


.. toctree::
   :maxdepth: 1
   :caption: Local preview

   local.rst


.. toctree::
   :maxdepth: 1
   :caption: Styling your slides

   style.rst


.. toctree::
   :maxdepth: 1
   :caption: API

   api.rst


.. toctree::
   :maxdepth: 1
   :caption: Maintaining your own server

   maintenance/env.rst


.. toctree::
   :maxdepth: 1
   :caption: Development

   development/dependencies.rst
   development/env.rst
